.. _examples:

Example Scripts
===============

Here are a few example scripts to get you started, including, as promised,
the scripts used for the clips of the demonstration video.


.. toctree::
   :maxdepth: 1
   
   moving_letters
   ukulele_concerto
   example_with_sound
   star_worms
   masked_credits
   painting_effect
   compo_from_image
   headblur
   the_end
   
   
   
   
